pub struct BoundsError { /* private fields */ }Expand description
The error type used by the trait implementations of Bounds in this crate.
Callers can think of this as a single unifying error value that combines
all implementations of Bounds in this crate. Internally, it’s an enum
with each variant corresponding to a single implementation of Bounds.
Each variant has a field containing a zero-sized RawBoundsError<B>,
where B is the type implementing Bounds.