ISOYear

Struct ISOYear 

pub struct ISOYear(/* private fields */);
The supported range of year numbers in the ISO 8601 week calendar.

This matches the supported range of Gregorian year numbers.

Implementations

Source

impl ISOYear

pub const MIN: i16 = <ISOYear as Bounds>::MIN

pub const MAX: i16 = <ISOYear as Bounds>::MAX

pub const LEN: i128

pub const fn error() -> BoundsError

pub fn check(n: impl Into<i64>) -> Result<i16, BoundsError>

pub const fn checkc(n: i64) -> Result<i16, BoundsError>

pub const fn checked_add(n1: i16, n2: i16) -> Result<i16, BoundsError>

pub fn checked_mul(n1: i16, n2: i16) -> Result<i16, BoundsError>