pub struct NthWeekday(/* private fields */);Expand description
The supported range of values for getting the “nth weekday” from a date.
Note that 0 is also invalid, but this is not expressed by
this single contiguous range.
Implementations
Sourceimpl NthWeekday
impl NthWeekday
pub const MIN: i32 = <NthWeekday as Bounds>::MIN
pub const MAX: i32 = <NthWeekday as Bounds>::MAX
pub const LEN: i128
pub const fn error() -> BoundsError
pub fn check(n: impl Into<i64>) -> Result<i32, BoundsError>
pub const fn checkc(n: i64) -> Result<i32, BoundsError>
pub const fn checked_add(n1: i32, n2: i32) -> Result<i32, BoundsError>
pub fn checked_mul(n1: i32, n2: i32) -> Result<i32, BoundsError>