pub struct NthWeekdayOfMonth(/* private fields */);Expand description
The supported range of values for getting the “nth weekday of a month” from a particular date.
Note that 0 is also invalid, but this is not expressed by
this single contiguous range. Note also that 5 or -5 can be invalid
if the provided month does not contain a 5th instance of the weekday
provided by the caller.
Implementations
Sourceimpl NthWeekdayOfMonth
impl NthWeekdayOfMonth
pub const MIN: i8 = <NthWeekdayOfMonth as Bounds>::MIN
pub const MAX: i8 = <NthWeekdayOfMonth as Bounds>::MAX
pub const LEN: i128
pub const fn error() -> BoundsError
pub fn check(n: impl Into<i64>) -> Result<i8, BoundsError>
pub const fn checkc(n: i64) -> Result<i8, BoundsError>
pub const fn checked_add(n1: i8, n2: i8) -> Result<i8, BoundsError>
pub fn checked_mul(n1: i8, n2: i8) -> Result<i8, BoundsError>