pub struct RangeError { /* private fields */ }Expand description
An error type that combines BoundsError with other custom error variants.
For example, a range error on the days of the month when constructing a date would ideally include the corresponding year and month. Otherwise the error message is likely to be much less useful than it could be.