pub struct RawBoundsError<B>(/* private fields */);Expand description
An error type that encodes information from an implementation of
Bounds.
The information encoded is used to write an error message in response to a value being out of bounds.
Implementations
Sourceimpl<B> RawBoundsError<B>
impl<B> RawBoundsError<B>
Sourcepub const fn new() -> RawBoundsError<B>
pub const fn new() -> RawBoundsError<B>
Create a new raw boundary error.
It is intended for B to implement the Bounds trait. But this
constructor technically does not require it. However, the Debug
and Display impls on this type do require it.