pub struct Rule {
pub start: DayTime,
pub end: DayTime,
}Expand description
A time zone transition rule.
This spells out a “range” of datetimes within a calendar year that should get a special daylight saving time offset from UTC.
Fields
start: DayTimeThe start of the time zone transition (e.g., daylight saving time).
end: DayTimeThe end of the time zone transition (e.g., daylight saving time).