TransitionCivilTime

Struct TransitionCivilTime 

pub struct TransitionCivilTime {
    pub second: i32,
}
Represents the civil time at which a time zone transition occurs.

Note that this does not use civil::TimeSecond because this may be longer than a single civil day (i.e., bigger than 86400). It can also be negative.

Fields

second: i32

The time in seconds. This may be negative.

Valid range is [-604_799, 604_799].

Implementations

Source

impl TransitionCivilTime

pub const DEFAULT: TransitionCivilTime

The “default” time for a time zone transition to occur.

This is used, as specified by POSIX, whenever a specific time of day is omitted from a POSIX time zone transition rule string.