Transition

Struct Transition 

pub struct Transition { /* private fields */ }
A representation a single time zone transition.

Implementations

Source

impl Transition

pub fn timestamp(&self) -> Timestamp

Returns the timestamp at which this transition began.

pub fn offset(&self) -> Offset

Returns the offset corresponding to this time zone transition. All instants at and following this transition’s timestamp (and before the next transition’s timestamp) need to apply this offset from UTC to get the civil or “local” time in the corresponding time zone.

pub fn abbreviation(&self) -> &Abbreviation

Returns the time zone abbreviation corresponding to this time zone transition.

pub fn dst(&self) -> Dst

Returns whether daylight saving time is enabled for this time zone transition.

pub fn into_offset_info(self) -> OffsetInfo

Consumes this transition and returns the underlying OffsetInfo.