The number of hours allowed in a time zone offset.
This number was somewhat arbitrarily chosen. In part because it’s
bigger than any current offset in actual use by a wide margin, and in
part because POSIX TZ strings require the ability to store offsets in
the range -24:59:59..=25:59:59. Note though that we make the range a
little bigger with -25:59:59..=25:59:59 so that negating an offset
always produces a valid offset.
Note that RFC 8536 actually allows offsets to be much bigger, namely,
in the range (-2^31, 2^31), where both ends are exclusive (-2^31
is explicitly disallowed, and 2^31 overflows a signed 32-bit
integer). But RFC 8536 does say that it should be in the range
[-89999, 93599], which matches POSIX. In order to keep our offset
small, we stick roughly to what POSIX requires.
Note that we support a slightly bigger range of offsets than Temporal.
Temporal seems to support only up to 23 hours, but we go up to 25
hours. This is done to support POSIX time zone strings, which also
require 25 hours (plus the maximal minute/second components).