pub struct UnixEpochDays(/* private fields */);Expand description
The supported range of days from the Unix epoch for the Gregorian calendar.
The range supported is based on the range of Unix timestamps that we support.
Implementations
Sourceimpl UnixEpochDays
impl UnixEpochDays
pub const MIN: i32 = <UnixEpochDays as Bounds>::MIN
pub const MAX: i32 = <UnixEpochDays as Bounds>::MAX
pub const LEN: i128
pub const fn error() -> BoundsError
pub fn check(n: impl Into<i64>) -> Result<i32, BoundsError>
pub const fn checkc(n: i64) -> Result<i32, BoundsError>
pub const fn checked_add(n1: i32, n2: i32) -> Result<i32, BoundsError>
pub fn checked_mul(n1: i32, n2: i32) -> Result<i32, BoundsError>