pub struct OffsetInfo { /* private fields */ }Expand description
Information associated with an offset when doing a time zone transition lookup.
Callers should generally only need the offset. This exposes additional information such as the time zone abbreviation or whether a timestamp is in daylight saving time or not.
Implementations
Sourceimpl OffsetInfo
impl OffsetInfo
Sourcepub fn offset(&self) -> Offset
pub fn offset(&self) -> Offset
Returns the offset corresponding to this time zone transition. All instants at and following this transition’s timestamp (and before the next transition’s timestamp) need to apply this offset from UTC to get the civil or “local” time in the corresponding time zone.
Sourcepub fn abbreviation(&self) -> &Abbreviation
pub fn abbreviation(&self) -> &Abbreviation
Returns the time zone abbreviation corresponding to this time zone transition.
Sourcepub fn into_abbreviation(self) -> Abbreviation
pub fn into_abbreviation(self) -> Abbreviation
Consumes this offset info and returns its abbreviation.