pub struct Transition { /* private fields */ }Expand description
A representation a single time zone transition.
Implementations
Sourceimpl Transition
impl Transition
Sourcepub fn offset(&self) -> Offset
pub fn offset(&self) -> Offset
Returns the offset corresponding to this time zone transition. All instants at and following this transition’s timestamp (and before the next transition’s timestamp) need to apply this offset from UTC to get the civil or “local” time in the corresponding time zone.
Sourcepub fn abbreviation(&self) -> &Abbreviation
pub fn abbreviation(&self) -> &Abbreviation
Returns the time zone abbreviation corresponding to this time zone transition.
Sourcepub fn dst(&self) -> Dst
pub fn dst(&self) -> Dst
Returns whether daylight saving time is enabled for this time zone transition.
Sourcepub fn into_offset_info(self) -> OffsetInfo
pub fn into_offset_info(self) -> OffsetInfo
Consumes this transition and returns the underlying OffsetInfo.